function object2frames(obj,frameSize, filename)

[pathstr,name,ext] = fileparts(filename);
pathstr=[pathstr '/' name];
[~,~,~] = mkdir(pathstr);

%define roundn
roundn = @(x,n) 10.^n .* round(x/10.^n);
radtodeg= @(x) x.*180./pi();
numbersOfCameras=12;

[cameras,~]=SpiralSampleSphere(numbersOfCameras,false);

[azimuth,elevation,r] = cart2sph(cameras(:,1),cameras(:,2),cameras(:,3));
azimuth=radtodeg(azimuth);
elevation=radtodeg(elevation);

cornerpoints=[min(obj.v(:,1)) min(obj.v(:,3)) min(obj.v(:,3));...
              max(obj.v(:,1)) max(obj.v(:,3)) max(obj.v(:,3))];
cornerpoints=roundn(cornerpoints,-8);
ranges = range(cornerpoints);

tMatrix = [1 0 0 0;... 
           0 1 0 0;...
           0 0 1 0;... 
           -(min(cornerpoints(:,1))+(ranges(1)/2))...
           -(min(cornerpoints(:,2))+(ranges(2)/2))...
           -(min(cornerpoints(:,3))+(ranges(3)/2))...
           1 ];

scalefactor=max(ranges)*10;
camera=cameras(1,:,:)*scalefactor;


parfor x=1:numbersOfCameras
    tMatrixRot=viewmtx(azimuth(x),elevation(x));
    tform = affine3d((tMatrix*tMatrixRot));
    v = transformPointsForward(tform,obj.v);
    f = obj.f;
    figHandle=figure('visible','off')
    patch('Vertices',v,'Faces',f,'FaceColor',[0.5 0.5 0.5],'EdgeColor','none');%,'FaceLighting', 'flat', 'AmbientStrength',0.6,'EraseMode','normal','EdgeLighting', 'gouraud','BackFaceLighting','lit')
    axis equal
    axis vis3d off
    axis off
    
    campos(camera)
    h=light('Style','local');
    h=camlight(h,'right');
    h=camlight(h,azimuth(x)-45,elevation(x)+45);
    set(figHandle,'PaperUnits','inches','PaperPosition',[0 0 frameSize])
    print(figHandle, '-dpng', fullfile(pathstr,[name,'_pos',int2str(x)]), '-r1');
    delete(figHandle);
    delete(h);
end
end

